Mobius.capacity. This function is an implementation of the TOMASO method (see Meyer and Roubens (2005)) in the particular ranking framework. The input data are given under the form of a set of alternatives and a partial weak order, each alternative being described according to a set of criteria. These well-known alternatives are called "prototypes". They represent alternatives for which the decision maker has an a priori knowledge and for which he/she is able to build a ranking. If the provided ranking (partial weak order) of the prototypes cannot be described by a Choquet integral, an approximative solution, which minimizes the "gap" between the given ranking and the one derived from the Choquet integral, is proposed. The problem is solved by quadratic programming.ls.ranking.capa.ident(n, k, C, rk, d, A.Shapley.preorder = NULL,
A.Shapley.interval = NULL, A.interaction.preorder = NULL,
A.interaction.interval = NULL, A.inter.additive.partition = NULL,
sigf = 5, maxiter = 20, epsilon = 1e-6)numeric containing the
number of elements of the set on which the object of class
Mobius.capacity is to be defined (in short, the number of criteria).numeric imposing that the solution is at
most a k-additive capacity (the Moebius transform of subsets whose cardinal is
superior to k vanishes).matrix containing the
n-column criteria matrix. Each line of this matrix
corresponds to a prototype.matrix containing the
constraints relative to the preorder of the prototypes. Each line
of this 2-column matrix corresponds to one constraint of the type
"the alternative i is prefered to the alternatinumeric containing the threshold value, i.e. the minimal "distance" between two neighbor alternatives in the given ranking (e.g. the difference in terms of the Choquet integral of the
a prototype with rank 3 and a prototypmatrix containing the
constraints relative to the preorder of the criteria. Each line
of this 3-column matrix corresponds to one constraint of the type
"the Shapley importance index of criterion i is gmatrix containing the
constraints relative to the quantitative importance of the
criteria. Each line of this 3-column matrix corresponds to one
constraint of the type "the Shapley importance index of criterion
matrix
containing the constraints relative to the preorder of the pairs of
criteria in terms of the Shapley interaction index. Each line of this 5-column matrix
corresponds to one constraint of the type "the Shaplematrix
containing the constraints relative to the type and the magnitude of
the Shapley interaction index for pairs of criteria. Each line of
this 4-column matrix corresponds to one constraint of the type
"the numeric
encoding a partition of the set of criteria imposing that there be
no interactions among criteria belonging to different classes
of the partition. The partition is to be given under the form of a
vectoipop function (quadratic programming)
of the ipop function (quadratic programming)
of the numeric containing the
threshold value for the monotonicity constraints, i.e. the
difference between the "weights" of two subsets whose cardinals
differ exactly by 1 must be greater than epsilon.Mobius.capacity containing the Moebius transform of the
k-additive solution.ipop (cf. ipop function of
the Mobius.capacity-class,
lin.prog.capa.ident,
mini.var.capa.ident,
mini.dist.capa.ident,
least.squares.capa.ident,
heuristic.ls.capa.ident,
entropy.capa.ident.arthur <- c(1, 1, 0.75, 0.25)
lancelot <- c(0.75, 0.75, 0.75, 0.75)
yvain <- c(1, 0.625, 0.5, 1)
perceval <- c(0.25, 0.5, 0.75, 0.75)
erec <- c(0.375, 1, 0.5 , 0.75)
P <- rbind(arthur, lancelot, yvain, perceval, erec)
# lancelot > erec; yvain > erec, erec > perceval, erec > arthur
rk.proto <- rbind(c(2,5), c(3,5), c(5,4), c(5,1))
n<-4
k<-2
d<-0.1
## search for a capacity which satisfies the constraints
lrc <- ls.ranking.capa.ident(n ,k, P, rk.proto, d)
lrcRun the code above in your browser using DataLab